#[repr(transparent)]pub struct Bufferingahb2vpb0(pub u32);Expand description
Buffering of write accesses on the Synchronous System configuration APB interface.
Tuple Fields
0: u32Implementations
Sourceimpl Bufferingahb2vpb0
impl Bufferingahb2vpb0
Sourcepub const fn inputmux0(&self) -> bool
pub const fn inputmux0(&self) -> bool
Enables buffering of write accesses on the peripheral input mux distribute APB interface:.
Sourcepub const fn set_inputmux0(&mut self, val: bool)
pub const fn set_inputmux0(&mut self, val: bool)
Enables buffering of write accesses on the peripheral input mux distribute APB interface:.
Sourcepub const fn set_i3c0(&mut self, val: bool)
pub const fn set_i3c0(&mut self, val: bool)
Enables buffering of write accesses on I3C0 APB interface.
Sourcepub const fn ctimer0(&self) -> bool
pub const fn ctimer0(&self) -> bool
Enables buffering of write accesses on CTIMER0 APB interface.
Sourcepub const fn set_ctimer0(&mut self, val: bool)
pub const fn set_ctimer0(&mut self, val: bool)
Enables buffering of write accesses on CTIMER0 APB interface.
Sourcepub const fn ctimer1(&self) -> bool
pub const fn ctimer1(&self) -> bool
Enables buffering of write accesses on CTIMER1 APB interface.
Sourcepub const fn set_ctimer1(&mut self, val: bool)
pub const fn set_ctimer1(&mut self, val: bool)
Enables buffering of write accesses on CTIMER1 APB interface.
Sourcepub const fn ctimer2(&self) -> bool
pub const fn ctimer2(&self) -> bool
Enables buffering of write accesses on CTIMER2 APB interface.
Sourcepub const fn set_ctimer2(&mut self, val: bool)
pub const fn set_ctimer2(&mut self, val: bool)
Enables buffering of write accesses on CTIMER2 APB interface.
Sourcepub const fn ctimer3(&self) -> bool
pub const fn ctimer3(&self) -> bool
Enables buffering of write accesses on CTIMER3 APB interface.
Sourcepub const fn set_ctimer3(&mut self, val: bool)
pub const fn set_ctimer3(&mut self, val: bool)
Enables buffering of write accesses on CTIMER3 APB interface.
Sourcepub const fn ctimer4(&self) -> bool
pub const fn ctimer4(&self) -> bool
Enables buffering of write accesses on CTIMER4 APB interface.
Sourcepub const fn set_ctimer4(&mut self, val: bool)
pub const fn set_ctimer4(&mut self, val: bool)
Enables buffering of write accesses on CTIMER4 APB interface.
Sourcepub const fn freqme(&self) -> bool
pub const fn freqme(&self) -> bool
Enables buffering of write accesses on freqme APB interface.
Sourcepub const fn set_freqme(&mut self, val: bool)
pub const fn set_freqme(&mut self, val: bool)
Enables buffering of write accesses on freqme APB interface.
Sourcepub const fn utick(&self) -> bool
pub const fn utick(&self) -> bool
Enables buffering of write accesses on micro Tick APB interface.
Sourcepub const fn set_utick(&mut self, val: bool)
pub const fn set_utick(&mut self, val: bool)
Enables buffering of write accesses on micro Tick APB interface.
Sourcepub const fn set_wwdt0(&mut self, val: bool)
pub const fn set_wwdt0(&mut self, val: bool)
Enables buffering of write accesses on wwdt0 APB interface.
Sourcepub const fn set_wwdt1(&mut self, val: bool)
pub const fn set_wwdt1(&mut self, val: bool)
Enables buffering of write accesses on wwdt1 APB interface.
Sourcepub const fn smart_dma0(&self) -> bool
pub const fn smart_dma0(&self) -> bool
Enables buffering of write accesses on SmartDMA0 APB interface.
Sourcepub const fn set_smart_dma0(&mut self, val: bool)
pub const fn set_smart_dma0(&mut self, val: bool)
Enables buffering of write accesses on SmartDMA0 APB interface.